@@ -29,9 +29,9 @@
 #include "gdbuserror.h"
 #include "gdbusprivate.h"
 #include "gdbusconnection.h"
+#include "gio-marshal.h"
 
 #include "glibintl.h"
-#include "gioalias.h"
 
 /**
  * SECTION:gdbusnameowning
@@ -340,6 +340,7 @@ request_name_cb (GObject      *source_object,
                                             "NameLost",
                                             "/org/freedesktop/DBus",
                                             client->name,
+                                            G_DBUS_SIGNAL_FLAGS_NONE,
                                             on_name_lost_or_acquired,
                                             client,
                                             NULL);
@@ -350,6 +351,7 @@ request_name_cb (GObject      *source_object,
                                             "NameAcquired",
                                             "/org/freedesktop/DBus",
                                             client->name,
+                                            G_DBUS_SIGNAL_FLAGS_NONE,
                                             on_name_lost_or_acquired,
                                             client,
                                             NULL);
@@ -450,7 +452,7 @@ connection_get_cb (GObject      *source_object,
 
 /**
  * g_bus_own_name_on_connection:
- * @connection: A #GDBusConnection that is not closed.
+ * @connection: A #GDBusConnection.
  * @name: The well-known name to own.
  * @flags: A set of flags from the #GBusNameOwnerFlags enumeration.
  * @name_acquired_handler: Handler to invoke when @name is acquired or %NULL.
@@ -478,7 +480,6 @@ g_bus_own_name_on_connection (GDBusConnection          *connection,
   Client *client;
 
   g_return_val_if_fail (G_IS_DBUS_CONNECTION (connection), 0);
-  g_return_val_if_fail (!g_dbus_connection_is_closed (connection), 0);
   g_return_val_if_fail (g_dbus_is_name (name) && !g_dbus_is_unique_name (name), 0);
 
   G_LOCK (lock);
@@ -634,6 +635,42 @@ typedef struct {
   GClosure *name_lost_closure;
 } OwnNameData;
 
+static OwnNameData *
+own_name_data_new (GClosure *bus_acquired_closure,
+                   GClosure *name_acquired_closure,
+                   GClosure *name_lost_closure)
+{
+  OwnNameData *data;
+
+  data = g_new0 (OwnNameData, 1);
+
+  if (bus_acquired_closure != NULL)
+    {
+      data->bus_acquired_closure = g_closure_ref (bus_acquired_closure);
+      g_closure_sink (bus_acquired_closure);
+      if (G_CLOSURE_NEEDS_MARSHAL (bus_acquired_closure))
+        g_closure_set_marshal (bus_acquired_closure, _gio_marshal_VOID__STRING);
+    }
+
+  if (name_acquired_closure != NULL)
+    {
+      data->name_acquired_closure = g_closure_ref (name_acquired_closure);
+      g_closure_sink (name_acquired_closure);
+      if (G_CLOSURE_NEEDS_MARSHAL (name_acquired_closure))
+        g_closure_set_marshal (name_acquired_closure, _gio_marshal_VOID__STRING);
+    }
+
+  if (name_lost_closure != NULL)
+    {
+      data->name_lost_closure = g_closure_ref (name_lost_closure);
+      g_closure_sink (name_lost_closure);
+      if (G_CLOSURE_NEEDS_MARSHAL (name_lost_closure))
+        g_closure_set_marshal (name_lost_closure, _gio_marshal_VOID__STRING);
+    }
+
+  return data;
+}
+
 static void
 own_with_closures_on_bus_acquired (GDBusConnection *connection,
                                    const gchar     *name,
@@ -649,6 +686,9 @@ own_with_closures_on_bus_acquired (GDBusConnection *connection,
   g_value_set_string (&params[1], name);
 
   g_closure_invoke (data->bus_acquired_closure, NULL, 2, params, NULL);
+
+  g_value_unset (params + 0);
+  g_value_unset (params + 1);
 }
 
 static void
@@ -666,6 +706,9 @@ own_with_closures_on_name_acquired (GDBusConnection *connection,
   g_value_set_string (&params[1], name);
 
   g_closure_invoke (data->name_acquired_closure, NULL, 2, params, NULL);
+
+  g_value_unset (params + 0);
+  g_value_unset (params + 1);
 }
 
 static void
@@ -683,6 +726,9 @@ own_with_closures_on_name_lost (GDBusConnection *connection,
   g_value_set_string (&params[1], name);
 
   g_closure_invoke (data->name_lost_closure, NULL, 2, params, NULL);
+
+  g_value_unset (params + 0);
+  g_value_unset (params + 1);
 }
 
 static void
@@ -732,41 +778,21 @@ g_bus_own_name_with_closures (GBusType                  bus_type,
                               GClosure                 *name_acquired_closure,
                               GClosure                 *name_lost_closure)
 {
-  OwnNameData *data;
-
-  data = g_new0 (OwnNameData, 1);
-
-  if (bus_acquired_closure != NULL)
-    {
-      data->bus_acquired_closure = g_closure_ref (bus_acquired_closure);
-      g_closure_sink (bus_acquired_closure);
-    }
-
-  if (name_acquired_closure != NULL)
-    {
-      data->name_acquired_closure = g_closure_ref (name_acquired_closure);
-      g_closure_sink (name_acquired_closure);
-    }
-
-  if (name_lost_closure != NULL)
-    {
-      data->name_lost_closure = g_closure_ref (name_lost_closure);
-      g_closure_sink (name_lost_closure);
-    }
-
   return g_bus_own_name (bus_type,
           name,
           flags,
           bus_acquired_closure != NULL ? own_with_closures_on_bus_acquired : NULL,
           name_acquired_closure != NULL ? own_with_closures_on_name_acquired : NULL,
           name_lost_closure != NULL ? own_with_closures_on_name_lost : NULL,
-          data,
+          own_name_data_new (bus_acquired_closure,
+                             name_acquired_closure,
+                             name_lost_closure),
           bus_own_name_free_func);
 }
 
 /**
  * g_bus_own_name_on_connection_with_closures:
- * @connection: A #GDBusConnection that is not closed.
+ * @connection: A #GDBusConnection.
  * @name: The well-known name to own.
  * @flags: A set of flags from the #GBusNameOwnerFlags enumeration.
  * @name_acquired_closure: (allow-none): #GClosure to invoke when @name is
@@ -791,28 +817,14 @@ g_bus_own_name_on_connection_with_closures (GDBusConnection          *connection
                                             GClosure                 *name_acquired_closure,
                                             GClosure                 *name_lost_closure)
 {
-  OwnNameData *data;
-
-  data = g_new0 (OwnNameData, 1);
-
-  if (name_acquired_closure != NULL)
-    {
-      data->name_acquired_closure = g_closure_ref (name_acquired_closure);
-      g_closure_sink (name_acquired_closure);
-    }
-
-  if (name_lost_closure != NULL)
-    {
-      data->name_lost_closure = g_closure_ref (name_lost_closure);
-      g_closure_sink (name_lost_closure);
-    }
-
   return g_bus_own_name_on_connection (connection,
           name,
           flags,
           name_acquired_closure != NULL ? own_with_closures_on_name_acquired : NULL,
           name_lost_closure != NULL ? own_with_closures_on_name_lost : NULL,
-          data,
+          own_name_data_new (NULL,
+                             name_acquired_closure,
+                             name_lost_closure),
           bus_own_name_free_func);
 }
 
@@ -909,6 +921,3 @@ g_bus_unown_name (guint owner_id)
       client_unref (client);
     }
 }
-
-#define __G_DBUS_NAME_OWNING_C__
-#include "gioaliasdef.c"
